<?php

/** ******************************************
 * LiteSpeed Web Server Plugin for DirectAdmin
 *
 * @author LiteSpeed Technologies, Inc. (https://www.litespeedtech.com)
 * @copyright (c) 2019-2020
 * @since 2.0
 * ******************************************* */

namespace LsPanel;

/**
 * @since 2.0
 */
class DAPluginLogEntry
{

    /**
     * @since 2.0
     * @var int
     */
    protected $lvl;

    /**
     * @since 2.0
     * @var string
     */
    protected $msg;

    /**
     * @since 2.0
     * @var null|string
     */
    protected $prefix;

    /**
     * @since 2.0
     * @var int[]
     */
    protected $timestamp;

    /**
     *
     * @since 2.0
     *
     * @param string  $msg
     * @param int     $lvl
     */
    public function __construct( $msg, $lvl )
    {
        $this->msg = $msg;
        $this->lvl = $lvl;
        $this->timestamp = time();
    }

    /**
     *
     * @since 2.0
     *
     * @param string  $msg
     */
    public function append( $msg )
    {
        $this->msg .= $msg;
    }

    /**
     *
     * @since 2.0
     *
     * @return int
     */
    public function getLvl()
    {
        return $this->lvl;
    }

    /**
     *
     * @since 2.0
     *
     * @return string
     */
    public function getMsg()
    {
        $msg = ($this->prefix == null) ? '' : "{$this->prefix} ";

        if ( $this->msg ) {
            $msg .= $this->msg;
        }

        return $msg;
    }

    /**
     *
     * @since 2.0
     *
     * @param int  $logLvl
     * @return string
     * @throws DAPluginException  Thrown indirectly.
     */
    public function getOutput( $logLvl )
    {
        if ( $this->lvl > $logLvl ) {
            return '';
        }

        $timestamp = date('Y-m-d H:i:s', $this->timestamp);
        $addTagInfo = DAPluginLogger::getAdditionalTagInfo();
        $lvl = '[' . DAPluginLogger::getLvlDescr($this->lvl) . ']';
        $msg = $this->getMsg();

        return "{$timestamp} {$addTagInfo} {$lvl}  {$msg}\n";
    }

}
