<?php

/** ******************************************
 * LiteSpeed Web Server Plugin for DirectAdmin
 *
 * @author Michael Alegre
 * @copyright (c) 2019-2022 LiteSpeed Technologies, Inc.
 * @since 2.0
 * ******************************************* */

namespace LsPanel\Extend;

use Lsc\Wp\Context\ContextOption;
use Lsc\Wp\Logger;
use LsPanel\DALiteSpeedUtil;
use LsPanel\DAPluginException;
use LsPanel\DAPluginLogger;

class DAPanelContextOption extends ContextOption
{

    /**
     *
     * @since 2.0
     *
     * @param string $panelName
     *
     * @throws DAPluginException  Thrown when getmypid() call returns boolean
     *     false.
     */
    public function __construct( $panelName )
    {
        if ( ($pid = getmypid()) === false ) {
            throw new DAPluginException(
                'Failed to get current PHP process ID when attempting to '
                    . 'construct DAPanelContextOption class object.'
            );
        }

        parent::__construct(
            $panelName,
            parent::FROM_CONTROL_PANEL,
            parent::IS_ROOT_ESCALATABLE,
            Logger::L_INFO,
            Logger::L_NONE,
            true,
            true
        );

        $this->expectedPermissions = self::IS_ROOT_ESCALATABLE;
        $this->loggerClass = '\LsPanel\Extend\DAPanelLogger';
        $this->lscwpVerClass = '\LsPanel\Extend\DAPanelPluginVersion';
        $this->scanDepth = 2;
        $this->batchTimeout = 60;
        $this->batchSize = 10;
        $this->logFile = DAPluginLogger::TEMP_LOG_BASE . "_$pid.log";

        if ( ($lswsHome = DALiteSpeedUtil::getLswsHome()) == ''
                || ($lswsRealPath = realpath($lswsHome)) === false ) {

            $lswsRealPath = '/usr/local/lsws';
        }

        $this->sharedTplDir = "$lswsRealPath/add-ons/webcachemgr/src/View/Tpl";
    }

}
