<?php

/** ******************************************
 * LiteSpeed Web Server Plugin for DirectAdmin
 *
 * @author    Michael Alegre
 * @copyright 2019-2023 LiteSpeed Technologies, Inc.
 * @since     2.0
 * ******************************************* */

namespace LsPanel\Extend;

use Lsc\Wp\LogEntry;
use Lsc\Wp\Logger;
use Lsc\Wp\LSCMException;
use LsPanel\DAEscalate;
use LsPanel\DAPluginException;

/**
 * Logger is a singleton
 *
 * @since 2.0
 */
class DAPanelLogger extends Logger
{

    /**
     *
     * @since 2.0
     *
     * @param LogEntry[] $entries
     *
     * @throws LSCMException  Rethrown when DAEscalate::escalate() call throws
     *     a DAPluginException exception.
     * @throws LSCMException  Thrown indirectly by $e->getOutput() call.
     */
    protected function writeToFile( array $entries )
    {
        $content = '';

        foreach ( $entries as $e ) {
            $content .= $e->getOutput($this->logFileLvl);
        }

        if ( $content != '' ) {

            if ( $this->logFile ) {
                file_put_contents(
                    $this->logFile,
                    $content,
                    FILE_APPEND | LOCK_EX
                );
            }
            else {
                error_log($content);
            }

            try {
                DAEscalate::escalate(true, DAEscalate::MGR_CMD_WRITE_TO_LOG);
            }
            catch ( DAPluginException $e ) {
                throw new LSCMException($e->getMessage(), $e->getCode());
            }
        }

        if ( file_exists($this->logFile) ) {
            unlink($this->logFile);
        }
    }

}
