<?php

/** ******************************************
 * LiteSpeed Web Server Plugin for DirectAdmin
 *
 * @author LiteSpeed Technologies, Inc. (https://www.litespeedtech.com)
 * @copyright (c) 2019-2020
 * @since 2.0
 * ******************************************* */

namespace LsPanel\Extend;

use \Lsc\Wp\LSCMException;
use \LsPanel\DAEscalate;
use \Lsc\Wp\PluginVersion;
use \LsPanel\DAPluginException;

/**
 * @since 2.0
 */
class DAPanelPluginVersion extends PluginVersion
{

    /**
     *
     * @since 2.0
     *
     * @throws LSCMException  Thrown indirectly.
     */
    protected function __construct()
    {
        parent::__construct();
    }

    /**
     *
     * @since 2.0
     *
     * @throws LSCMException
     */
    public function setCurrentVersion()
    {
        try {
            $activeVersion = DAEscalate::escalate(
                true,
                DAEscalate::MGR_CMD_GET_CURR_VER
            );
        }
        catch ( DAPluginException $e ) {
            throw new LSCMException($e->getMessage(), $e->getCode());
        }

        $this->currVersion = $activeVersion;
    }

    /**
     *
     * @since 2.0
     *
     * @param string   $version  Valid LSCWP version.
     * @param boolean  $init     True when trying to set initial active
     *                           version.
     * @throws LSCMException
     */
    public function setActiveVersion( $version, $init = false )
    {
        try {
            DAEscalate::escalate(
                true,
                DAEscalate::MGR_CMD_SET_ACTIVE_VER,
                array('ver' => $version, 'init' => $init)
            );
        }
        catch ( DAPluginException $e ) {
            throw new LSCMException($e->getMessage(), $e->getCode());
        }
    }

    /**
     *
     * @since 2.0
     *
     * @param boolean  $isforced
     * @throws LSCMException
     */
    protected function refreshVersionList( $isforced = false )
    {
        clearstatcache();

        if ( $isforced || !file_exists($this->versionFile)
                || (time() - filemtime($this->versionFile)) > 86400 ) {

            try {
                DAEscalate::escalate(
                    true,
                    DAEscalate::MGR_CMD_REFRESH_VER_LIST
                );
            }
            catch ( DAPluginException $e ) {
                throw new LSCMException($e->getMessage(), $e->getCode());
            }
        }
    }

}
