<?php

/** ******************************************
 * LiteSpeed Web Server Plugin for DirectAdmin
 *
 * @author LiteSpeed Technologies, Inc. (https://www.litespeedtech.com)
 * @copyright (c) 2019-2020
 * @since 2.0
 * ******************************************* */

namespace LsPanel\View\Model;

use \LsPanel\DALiteSpeedUtil;
use \LsPanel\DAPluginException;

/**
 * @since 2.0
 */
class TransferLicenseViewModel extends BaseViewModel
{

    /**
     * @since 2.0
     * @var string
     */
    const FLD_LIC_USABLE = 'licUsable';

    /**
     * @since 2.0
     * @var string
     */
    const FLD_LIC_STATUS_OUTPUT = 'licStatusOutput';

    /**
     * @since 2.0
     * @var string
     */
    const FLD_LIC_MIGRATED = 'licMigrated';

    /**
     * @since 2.1
     * @var string
     */
    const FLD_LSWS_HOME = 'lswsHome';

    /**
     *
     * @since 2.0
     *
     * @throws DAPluginException  Thrown indirectly.
     */
    public function __construct()
    {
        parent::__construct();

        $this->init();
    }

    /**
     *
     * @since 2.0
     *
     * @throws DAPluginException  Thrown indirectly.
     */
    private function init()
    {
        $this->setLicStatusData();
        $this->setLswsHomeData();
    }

    /**
     *
     * @since 2.0
     *
     * @throws DAPluginException  Thrown indirectly.
     */
    private function setLicStatusData()
    {
        $licUsable = $migrated = false;
        $output = '';

        $return_var = DALiteSpeedUtil::getCurrentLicenseStatus($output);

        if ( $return_var == 0) {
            $licUsable = true;

            if ( preg_match('/ -[0-9]+ /', $output) ) {
                $migrated = true;
            }
        }

        $this->tplData[self::FLD_LIC_USABLE] = $licUsable;
        $this->tplData[self::FLD_LIC_STATUS_OUTPUT] = $output;
        $this->tplData[self::FLD_LIC_MIGRATED] = $migrated;

    }

    /**
     *
     * @since 2.1
     */
    private function setLswsHomeData()
    {
        $this->tplData[self::FLD_LSWS_HOME] = DALiteSpeedUtil::getLswsHome();
    }

    /**
     *
     * @since 2.0
     *
     * @return string
     */
    public function getTpl()
    {
        return realpath(__DIR__ . '/../Tpl') . '/TransferLicense.tpl';
    }

}
