<?php

/** ******************************************
 * LiteSpeed Web Server Plugin for DirectAdmin
 *
 * @author    Michael Alegre
 * @copyright 2019-2023 LiteSpeed Technologies, Inc.
 * @since     2.0
 * ******************************************* */

namespace LsPanel;

use Lsc\Wp\LSCMException;
use LsPanel\DALiteSpeedUtil as Util;

require_once __DIR__ . '/autoloader.php';

/**
 *
 * @since 2.0
 *
 * @param string  $msg
 */
function displayCustomExceptionMsg( $msg )
{
    if ( defined('LSWS_AJAX_CALL') && LSWS_AJAX_CALL ) {
        echo "HTTP/1.1 200 OK\nContent-Type: text/html\n\n";
    }

    $displayMsg = "Exception Caught - $msg";

    try {
        DAPluginLogger::error($msg);
    }
    catch ( DAPluginException $e ) {
        $displayMsg .=
            "<br />Exception Caught - Failed to log previous Exception message";
    }

    echo "<h1>$displayMsg</h1>";
}

try {

    if ( ($pid = getmypid()) === false ) {
        throw new DAPluginException(
            'Failed to get current PHP process ID when attempting to set '
                . 'DAPluginLogger additional tag info.'
        );
    }

    DAPluginLogger::Initialize();
    DAPluginLogger::setAdditionalTagInfo(
        "[{$_SERVER['REMOTE_ADDR']}-$pid]"
    );
    DAPluginLogger::preCreateLogFile();

    /**
     * Set PHP session ID based on DirectAdmin session ID. Because the plugin
     * is run using a CLI PHP binary, PHP session ID must be set manually.
     */
    session_id(md5($_SERVER['SESSION_ID']));

    if ( basename(realpath('/usr/local/lsws/bin/lshttpd')) == 'openlitespeed' ) {
        Util::define_wrapper('LSWS_SERVER_TYPE', 'open');
        $controller = new DAOpenLiteSpeedController();
    }
    else {
        Util::define_wrapper('LSWS_SERVER_TYPE', 'ent');
        $controller = new DALiteSpeedController();
    }

    $controller->run();
}
catch ( DAPluginException $e ) {
    displayCustomExceptionMsg($e->getMessage());
}
/** @noinspection PhpRedundantCatchClauseInspection */
catch ( LSCMException $e )
{
    displayCustomExceptionMsg($e->getMessage());
}
